@@ -123,4 +123,14 @@ def fis_tools_pre_ranking_mi(mutual_selector, predictors_df, modo = 'tabla'):
 def fis_tools_pre_ranking_per(predictoras,permutacion):
     ranking_per = pd.DataFrame({'variable': predictoras.columns, 'importancia_per': permutacion.importances_mean}).sort_values(by = 'importancia_per', ascending = False)
     ranking_per['ranking_per'] = np.arange(0,ranking_per.shape[0])
-    return(ranking_per)
\ No newline at end of file
+    return(ranking_per)
+    
+def fis_tools_pre_ranking_tot(rank_mi, rank_rfe,rank_per,modo='tabla'):
+    ranking_tot = pd.merge(pd.merge(rank_mi,rank_rfe),rank_per)
+    ranking_tot['puntos'] = ranking_tot.ranking_mi + ranking_tot.ranking_rfe + ranking_tot.ranking_per
+    ranking_tot.sort_values(by = 'puntos', inplace=True)
+    ranking_tot['ranking_tot'] = range(0,len(ranking_tot.variable))
+    if modo == 'tabla':
+        return(ranking_tot)
+    else:
+        ranking_tot.set_index('variable').puntos.sort_values(ascending = False).plot.barh(figsize = (8,10));
\ No newline at end of file
